gs_quant.timeseries.datetime.union — gs_quant 0.1 documentation

# gs_quant.timeseries.datetime.union

`union`(x)

  Fill in missing dates or times of one series with another

  Parameters

    x (`List`[`Series`]) – an array of timeseries

  Return type

    `Series`

  Returns

    combined series

  Usage

  Starting from \(i=1\), takes points from series \(x_i\). Where points are missing from \(x_i\), returns points from \(x_{i+1}\).

  Examples

  Union of two series:

      >>> x = generate_series(100)
      >>> y = generate_series(100)
      >>> union([x, y])

  See also

  `prepend()`